==> 1.4.6.tar.gz: lib/src/fragment/fragment.dart <==
part of 'fragment_container.dart';

abstract class Fragment extends StatefulWidget {
  @override
  FragmentKey get key => super.key as FragmentKey;

  const Fragment({required FragmentKey key}) : super(key: key);

  @override
  FragmentState<Fragment> createState();
}

abstract class FragmentState<T extends Fragment> extends State<T> {
  late FragmentContainerState _container;
  String? _args;

  FragmentManager get manager => _container;

  dynamic get args => _args?.let(jsonDecode);

  @override
  void initState() {
    super.initState();
    _container = requireNotNull(context.findAncestorStateOfType<FragmentContainerState>(),
        message: () => 'Fragment must belong to a FragmentContainer');
    _container._onFragmentAttached(this);
  }

  void setArguments(String? args) => _args != args
      ? mounted
          ? setState(() => _args = args)
          : _args = args
      : null;

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties
      ..add(DiagnosticsProperty<FragmentManager>('manager', manager))
      ..add(DiagnosticsProperty('args', args));
  }
}

@optionalTypeArgs
class FragmentKey<T extends FragmentState> extends GlobalKey<T> {
  final String name;

  const FragmentKey(this.name) : super.constructor();

  @override
  bool operator ==(Object other) => other is FragmentKey<T> && identical(other.name, name);

  @override
  int get hashCode => identityHashCode(name);

  @override
  String toString() => 'FragmentKey($name)';
}

==> 1.4.7.tar.gz: lib/src/fragment/fragment.dart <==
part of 'fragment_container.dart';

abstract class Fragment extends StatefulWidget {
  @override
  FragmentKey get key => super.key as FragmentKey;

  const Fragment({required FragmentKey key}) : super(key: key);

  @override
  FragmentState<Fragment> createState();
}

abstract class FragmentState<T extends Fragment> extends State<T> {
  late FragmentContainerState _container;
  String? _args;
  bool _active = false;

  FragmentManager get manager => _container;

  dynamic get args => _args?.let(jsonDecode);

  bool get active => _active;

  @override
  void initState() {
    super.initState();
    _container = requireNotNull(context.findAncestorStateOfType<FragmentContainerState>(),
        message: () => 'Fragment must belong to a FragmentContainer');
    _container._onFragmentAttached(this);
  }

  @override
  void dispose() {
    _container._onFragmentDetached(this);
    super.dispose();
  }

  @mustCallSuper
  void onResume() => _active = true;

  @mustCallSuper
  void onPause() => _active = false;

  void setArguments(String? args) => _args != args
      ? mounted
          ? setState(() => _args = args)
          : _args = args
      : null;

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties
      ..add(DiagnosticsProperty<FragmentManager>('manager', manager))
      ..add(DiagnosticsProperty('args', args))
      ..add(DiagnosticsProperty<bool>('active', active));
  }
}

@optionalTypeArgs
class FragmentKey<T extends FragmentState> extends GlobalKey<T> {
  final String name;

  const FragmentKey(this.name) : super.constructor();

  @override
  bool operator ==(Object other) => other is FragmentKey<T> && identical(other.name, name);

  @override
  int get hashCode => identityHashCode(name);

  @override
  String toString() => 'FragmentKey($name)';
}
